# Welcome to speakme 0.1.1 : Speech Assistant System 

speakme 0.1.1 system has 'Markos' - your personal voice assistant / software agent that can perform tasks or services for an individual based on verbal commands i.e. 
by interpreting human speech and respond via synthesized voices. 
Users can ask their assistants’ questions, control home automation devices, and media playback via voice, and manage other basic tasks such as email, 
to-do lists, open or close any application etc with verbal commands.

Markos has strong recommandation ability, which help you in verious decision making. ex. he will recommend you a movie as per your choice.

## Getting Started

You will be able to extarct .whl file with the help of python foundation and install the library using <b>pip</b>

### Prerequisites and Installing

What things you need to install the software and how to install them

```
. Browser driver : ex. for google crome ( cromedriver.exe ) 

Require below componants using pip

. pyttsx3
. datetime
. smtplib
. os
```

## Running the tests

Install speakme 0.1.1 using pip command on Command prompt


## Deployment

Deployed and Comaptible with Python 3 and above

## Built With

* [Python 3](https://docs.python.org/fr/3.6/) - Scripting language used
* [Pypi](https://pypi.org/) - The Python Package Index - library Dependency Management

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/your/project/tags). 

## Authors and Contributor

* **Tejas Bhor** - [tejasjbhor](https://github.com/tejasjbhor)

## License

This project is licensed under the MIT License - see the [LICENSE.md](https://github.com/tejasjbhor/NLP/blob/master/LICENSE) file for details

## Acknowledgments

* Python Foundation : For delpoying library

## Thanks

To you, for using the library, for helping me to make it faster and better, for learn with it and for releasing your
code to make the knowledge and the science open for the rest of humanity.

## Warning

It has been developed with  python >= 3.5 in mind, so it won't probably work on lower versions (i.e. no python 2.X
support).

